using System;
using System.ComponentModel;
using System.Drawing.Design;
using System.Collections.Generic;
using System.Windows.Forms;
using System.Windows.Forms.Design;
using System.Text;
using PluginCore.Managers;
using PluginCore;

namespace FDTracer
{
    [Serializable]
    public class Settings
    {
        private String traceOutputFileName = "C:\\Documents and Settings\\{user}\\Application Data\\Macromedia\\Flash Player\\Logs\\flashlog.txt";
        private Boolean alwaysOpenPanel = false;
        private Boolean colourWarnings = false;
        
        /// <summary> 
        /// Get and sets the TraceOutputFileName
        /// </summary>
        [Category("Debug Flash Player"),
        DisplayName("Log File"),
        Description("Flash Player trace log file"), 
         DefaultValue("C:\\Documents and Settings\\{user}\\Application Data\\Macromedia\\Flash Player\\Logs\\flashlog.txt")]
        [Editor(typeof(FileNameEditor), typeof(UITypeEditor))]
        public String TraceOutputFileName 
        {
            get { return traceOutputFileName; }
            set 
            { 
                traceOutputFileName = value;
                DataEvent de = new DataEvent(EventType.Command, "FDTracer.SettingChange", "TraceOutputFileName");
                EventManager.DispatchEvent(this, de);
            }
        }

        /// <summary> 
        /// Get and sets the ShowPanel
        /// </summary>
        [Category("Panel"),
        DisplayName("Open Panel On Compile"), 
        Description("Always open the FDTracer panel when a compile completes"),
         DefaultValue(false)]
        public Boolean AlwaysOpenPanel
        {
            get { return alwaysOpenPanel; }
            set 
            {
                alwaysOpenPanel = value;
                DataEvent de = new DataEvent(EventType.Command, "FDTracer.SettingChange", "AlwaysOpenPanel");
                EventManager.DispatchEvent(this, de);
            }
        }

        /// <summary> 
        /// Colour warnings and errors
        /// </summary>
        [Category("Panel"),
        DisplayName("Colour Warnings and Errors"),
        Description("Colours warning and error statements"),
         DefaultValue(true)]
        public Boolean ColourWarnings
        {
            get { return colourWarnings; }
            set 
            { 
                colourWarnings = value;
                DataEvent de = new DataEvent(EventType.Command, "FDTracer.SettingChange", "ColourWarnings");
                EventManager.DispatchEvent(this, de);
            }
        }

     }
}
